@@ -52,6 +52,7 @@ main_build_database_progress_cb (GvaProcess *process,
 
                 progress = gva_process_get_progress (process);
                 fraction = (gdouble) progress / (gdouble) total_supported;
+                fraction = CLAMP (fraction, 0.0, 1.0);
         }
 
         progress_bar = GTK_PROGRESS_BAR (GVA_WIDGET_MAIN_PROGRESS_BAR);
@@ -138,7 +139,7 @@ gva_main_build_database (GError **error)
                 return FALSE;
 
         context_id = gva_main_statusbar_get_context_id (G_STRFUNC);
-        total_supported = gva_xmame_get_total_supported (NULL);
+        total_supported = gva_mame_get_total_supported (NULL);
 
         gva_main_statusbar_push (context_id, _("Building game database..."));
         gtk_widget_show (GVA_WIDGET_MAIN_PROGRESS_BAR);
